//
// external.cpp: externally .Call'able functions in lme4stub
//
// Copyright (C)       2011-2012 Douglas Bates, Martin Maechler and Ben Bolker
//
// This file is part of lme4stub.

#include "predModule.h"

extern "C" {
    typedef   Eigen::MatrixXd Mat;
    typedef   Eigen::Map<Mat> MMat;

    using      Rcpp::XPtr;  
    using      lme4stub::merPredD;

    SEXP isNullExtPtr(SEXP Ptr) {
        void *ptr = R_ExternalPtrAddr(Ptr);
        return ::Rf_ScalarLogical(ptr == (void*)NULL);
    }

    SEXP merPredDCreate(SEXP Xs) {
        BEGIN_RCPP;
        merPredD *ans = new merPredD(Xs);
        return wrap(XPtr<merPredD>(ans, true));
        END_RCPP;
    }
}

#include <R_ext/Rdynload.h>

#define CALLDEF(name, n)  {#name, (DL_FUNC) &name, n}

static R_CallMethodDef CallEntries[] = {
    CALLDEF(merPredDCreate, 1), // generate external pointer
};

/** Initializer for lme4stub, called upon loading the package.
 *
 *  Register routines that can be called directly from R.
 *  Initialize CHOLMOD and require the LL' form of the factorization.
 *  Install the symbols to be used by functions in the package.
 */
extern "C"
void R_init_lme4stub(DllInfo *dll)
{
    R_registerRoutines(dll, NULL, CallEntries, NULL, NULL);
    R_useDynamicSymbols(dll, (Rboolean)FALSE);
}
